import Lib
main = basicTest defaultConfig
